@@ -27,22 +27,16 @@ from io import BytesIO
 from subprocess import Popen, PIPE
 
 from dateutil.tz import tzlocal
-# The unittest module got a significant overhaul
-# in 2.7, so if we're in 2.6 we can use the backported
-# version unittest2.
-if sys.version_info[:2] == (2, 6):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 
 from nose.tools import assert_equal
 
 import botocore.loaders
 import botocore.session
 from botocore.awsrequest import AWSResponse
-from botocore.compat import six
-from botocore.compat import urlparse
-from botocore.compat import parse_qs
+from botocore.compat import (
+    parse_qs, six, urlparse, HAS_CRT
+)
 from botocore import utils
 from botocore import credentials
 from botocore.stub import Stubber
@@ -77,6 +71,15 @@ def skip_if_windows(reason):
     return decorator
 
 
+def requires_crt(reason=None):
+    if reason is None:
+        reason = "Test requires awscrt to be installed"
+
+    def decorator(func):
+        return unittest.skipIf(not HAS_CRT, reason)(func)
+    return decorator
+
+
 def random_chars(num_chars):
     """Returns random hex characters.
 
@@ -520,9 +523,9 @@ class StubbedSession(botocore.session.Session):
         self._client_stubs[service_name] = stubber
         return client
 
-    def stub(self, service_name):
+    def stub(self, service_name, *args, **kwargs):
         if service_name not in self._client_stubs:
-            self.create_client(service_name)
+            self.create_client(service_name, *args, **kwargs)
         return self._client_stubs[service_name]
 
     def activate_stubs(self):
